pub struct SessionEventWriter { /* private fields */ }Expand description
A convenience wrapper that stamps the user and session onto every append.
Implementations
Sourceimpl SessionEventWriter
impl SessionEventWriter
Sourcepub fn new(
log: Arc<dyn MemoryEventLog>,
user_id: UserId,
session_id: SessionId,
) -> Self
pub fn new( log: Arc<dyn MemoryEventLog>, user_id: UserId, session_id: SessionId, ) -> Self
Bind a log to one user and logical session.
Sourcepub async fn append(
&self,
turn_id: Option<TurnId>,
payload: MemoryEvent,
) -> Result<(), MemoryError>
pub async fn append( &self, turn_id: Option<TurnId>, payload: MemoryEvent, ) -> Result<(), MemoryError>
Append an event for a specific turn.
Sourcepub fn session_id(&self) -> &SessionId
pub fn session_id(&self) -> &SessionId
The bound logical session.