pub fn default_episodic_ttl(
kind: MemoryKind,
scope: TemporalScope,
) -> Option<Duration>Expand description
Default time-to-live for an episodic memory, by scope and kind (24.2).
pub fn default_episodic_ttl(
kind: MemoryKind,
scope: TemporalScope,
) -> Option<Duration>Default time-to-live for an episodic memory, by scope and kind (24.2).