pub struct ProposedMemory {Show 19 fields
pub fingerprint: FactFingerprint,
pub subject: EntityRef,
pub predicate: CanonicalPredicate,
pub value: MemoryValue,
pub statement: String,
pub evidence_summary: String,
pub kind: MemoryKind,
pub temporal_scope: TemporalScope,
pub explicitness: Explicitness,
pub confidence: f32,
pub evidence: EvidenceCounters,
pub persistence: ProposedPersistence,
pub expected_expiry: Option<DateTime<Utc>>,
pub mutation_intent: Option<MutationIntent>,
pub sensitivity: SensitivityClass,
pub qualifier: Option<String>,
pub session_id: SessionId,
pub turn_id: TurnId,
pub tags: Vec<String>,
}Expand description
A memory consolidation is asking to be allowed to write.
Fields
fingerprint: FactFingerprintDeduplication key.
subject: EntityRefSubject of the fact.
predicate: CanonicalPredicateCanonical predicate.
value: MemoryValueValue side.
statement: StringNatural-language rendering.
evidence_summary: StringWhy the engine believes it.
kind: MemoryKindProposed kind.
temporal_scope: TemporalScopeExpected persistence class.
explicitness: ExplicitnessStrongest explicitness behind it.
confidence: f32Aggregated confidence.
evidence: EvidenceCountersEvidence counters.
persistence: ProposedPersistenceRetention proposal.
expected_expiry: Option<DateTime<Utc>>Expiry for episodic proposals.
mutation_intent: Option<MutationIntent>Explicit command behind it, if any.
sensitivity: SensitivityClassPrivacy classification.
qualifier: Option<String>Context qualifier distinguishing coexisting facts.
session_id: SessionIdSession the evidence came from.
turn_id: TurnIdLast turn the evidence came from.
Search tags derived from the evidence.
Implementations
Sourceimpl ProposedMemory
impl ProposedMemory
Sourcepub fn into_canonical(
self,
owner: &UserId,
id: MemoryId,
status: MemoryStatus,
now: DateTime<Utc>,
) -> CanonicalMemory
pub fn into_canonical( self, owner: &UserId, id: MemoryId, status: MemoryStatus, now: DateTime<Utc>, ) -> CanonicalMemory
Materialize the proposal as a canonical record owned by owner.