pub fn proposal_from(memory: &CanonicalMemory) -> ProposedMemoryExpand description
Build a resolver-ready proposal for tests and callers that already have a canonical record in hand.
pub fn proposal_from(memory: &CanonicalMemory) -> ProposedMemoryBuild a resolver-ready proposal for tests and callers that already have a canonical record in hand.