pub fn memory_tools(session: Arc<MemorySession>) -> ToolCompositeExpand description
Both memory tools, as a composite that can be combined with |.
let tools = memory_tools(session) | T::google_search();pub fn memory_tools(session: Arc<MemorySession>) -> ToolCompositeBoth memory tools, as a composite that can be combined with |.
let tools = memory_tools(session) | T::google_search();